@@ -402,7 +402,7 @@ def _checkDataDirOptionValue(data_dir, option_name):
     if not os.path.isdir(src):
         Tracing.options_logger.sysexit(
             "Error, malformed '%s' value, must specify existing source data directory, not '%s' as in '%s'."
-            % (option_name, dst, data_dir)
+            % (option_name, src, data_dir)
         )
 
 
@@ -606,10 +606,11 @@ the Python download page."""
 
     # Check onefile tempdir spec.
     if options.onefile_tempdir_spec:
-        _checkOnefileTargetSpec()
-
         _warnOnefileOnlyOption("--onefile-tempdir-spec")
 
+        if options.is_onefile:
+            _checkOnefileTargetSpec()
+
     # Check onefile splash image
     if options.splash_screen_image:
         if not os.path.exists(options.splash_screen_image):
@@ -1060,6 +1061,15 @@ The Python without GIL is only experimentally supported by \
 and recommended only for use in Nuitka development and testing."""
         )
 
+    if python_version == 0x3D4 and isWin32Windows() and isCPythonOfficialPackage():
+        Tracing.general.sysexit(
+            """\
+Due to a CPython bug of 3.13.4 precisely (not <3.13.4 and >3.14.5) \
+it's not possible to use Nuitka with this Python version, as it \
+broke the separation between GIL and no-GIL for the link \
+library. Please upgrade/downgrade to a supported micro version."""
+        )
+
     default_reference_mode = (
         "runtime" if shallMakeModule() or isStandaloneMode() else "original"
     )
@@ -1120,6 +1130,8 @@ and recommended only for use in Nuitka development and testing."""
         _warnOSSpecificOption("--macos-app-protected-resource", "Darwin")
     if options.macos_app_mode is not None:
         _warnOSSpecificOption("--macos-app-mode", "Darwin")
+    if options.macos_prohibit_multiple_instances:
+        _warnOSSpecificOption("--macos-prohibit-multiple-instances", "Darwin")
 
     if options.msvc_version:
         if isMSYS2MingwPython() or isPosixWindows():
@@ -2480,6 +2492,14 @@ def isMacOSUiElementApp():
     return options.macos_app_mode == "ui-element"
 
 
+def shallMacOSProhibitMultipleInstances():
+    """*bool*, derived from ``--macos-prohibit-multiple-instances``"""
+    if not isMacOS():
+        return False
+
+    return options.macos_prohibit_multiple_instances
+
+
 _python_flags = None
 
 
